@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 import os.path as osp
-import logging, subprocess, os, time, sys
+import logging, subprocess, os, time, sys, glob
 from contextlib import contextmanager
 
 from . import path as seup
@@ -464,6 +464,17 @@ def get_implementation(implementation_name):
         return None
     return implementations[implementation_name]
 
+
+PREFERRED_IMPL = None
+
+def set_preferred_implementation(implementation):
+    if is_string(implementation):
+        implementation = implementations[implementation]
+    global PREFERRED_IMPL
+    PREFERRED_IMPL = implementation
+    logger.info('Set implementation %s as preferred', PREFERRED_IMPL)
+
+
 def best_implementation(cmd_name, path=None):
     """
     Given a command name, returns an installed implementation that has this command
@@ -475,6 +486,8 @@ def best_implementation(cmd_name, path=None):
         preferred_order = [ eos, gfal, pyxrd, xrd]
     else:
         preferred_order = [ xrd, gfal, pyxrd, eos ]
+    if PREFERRED_IMPL:
+        preferred_order.insert(0, PREFERRED_IMPL)
     # Return first one that's installed
     for implementation in preferred_order:
         if implementation.is_installed() and hasattr(implementation, cmd_name):
@@ -708,6 +721,23 @@ def listdir_recursive(directory, stat=False, implementation=None):
     return contents
 
 
+def expand_wildcards(pats):
+    """
+    Expands patterns into full paths, regardless of whether the patterns
+    point to a remote or local place
+    """
+    expanded = []
+    for pat in pats:
+        if '*' in pat:
+            if path.has_protocol(pat):
+                expanded.extend(ls_wildcard(pat))
+            else:
+                expanded.extend(glob.glob(pat))
+        else:
+            expanded.append(pat)
+    return expanded
+
+
 def _sorted_paths_from_set(relpaths_set, relpaths, contents):
     """
     Used internally by `diff`. For every element in `relpaths_set`,
